@@ -28,7 +28,13 @@ def initialize(session, stage, board):
         here = Path(__file__).parent
         parameter_path = here/'parameters.yaml'
         parameters_yaml = YAML()
-        parameters = parameters_yaml.load(parameter_path)
+        if parameter_path.exists():
+            parameters = parameters_yaml.load(parameter_path)
+        else:
+            parameters = recordingconfig.parameters_for_yaml
+            with open(parameter_path,'w') as outfile:
+                parameters_yaml.dump(parameters, outfile)
+
 
         try:
             rotation_entry = parameters["saved"]["rotations"]
@@ -90,7 +96,7 @@ def initialize(session, stage, board):
     
         else:
         
-            sys.exit('Recording Cancelled')
+            sys.exit('Recording Canceled')
 # %% Stage Two Initalization
     if stage == 2:
         # session.sessionPath = filepath/'Data'/session.sessionID #create a session path based on the sessionID
@@ -103,11 +109,11 @@ def initialize(session, stage, board):
 
         #from the config settings add the camera input parameters to parameter dictionary
         session.parameterDictionary = session.session_settings['recording_parameters']['ParameterDict']
-        session.rotationInputs = session.session_settings['recording_parameters']['RotationInputs']
-
+        rotationDict = session.session_settings['recording_parameters']['RotationInputs']
+        session.rotationInputs = list(rotationDict.values())
         #initialize the path to the timestamp csv
-        csvName = session.sessionID + '.csv'
-        csvPath = session.sessionPath/csvName
+        csvName = session.sessionID + '_timestamps.csv'
+        csvPath = session.rawVidPath/csvName
 
         #read CSV data, turn it into a data frame
         timeStampData = pd.read_csv (csvPath)
